@@ -1,5 +1,5 @@
 package HTTP::Proxy::BodyFilter::save;
-
+$HTTP::Proxy::BodyFilter::save::VERSION = '0.302';
 use strict;
 use HTTP::Proxy;
 use HTTP::Proxy::BodyFilter;
@@ -171,9 +171,11 @@ sub will_modify { 0 }
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
-HTTP::Proxy::BodyFilter::save - A filter that saves transfered data to a file
+HTTP::Proxy::BodyFilter::save - A filter that saves transferred data to a file
 
 =head1 SYNOPSIS
 
@@ -184,20 +186,20 @@ HTTP::Proxy::BodyFilter::save - A filter that saves transfered data to a file
 
     # save RFC files as we browse them
     $proxy->push_filter(
-        path => qr!/rfc\d+.txt!,
-        mime => 'text/plain',
+        path     => qr!/rfc\d+.txt!,
+        mime     => 'text/plain',
         response => HTTP::Proxy::BodyFilter::save->new(
             template => '%f',
             prefix   => 'rfc',
             keep_old => 1,
-        );
+        )
     );
 
     $proxy->start;
 
 =head1 DESCRIPTION
 
-The HTTP::Proxy::BodyFilter::save filter can save HTTP messages (responses
+The L<HTTP::Proxy::BodyFilter::save> filter can save HTTP messages (responses
 or request) bodies to files. The name of the file is determined by a
 template and the URI of the request.
 
@@ -285,14 +287,14 @@ other template-related options (C<no_host>, C<no_dirs>, C<cut_dirs>
 and C<prefix>) are ignored.
 
 The C<filename> option expects a reference to a subroutine. The subroutine
-will receive the HTTP::Message object and must return a string which
+will receive the L<HTTP::Message> object and must return a string which
 is the path of the file to be created (an absolute path is recommended,
 but a relative path is accepted).
 
 Returning C<""> or C<undef> will prevent the creation of the file.
 This lets a filter decide even more precisely what to save or not,
 even though this should be done in the match subroutine (see
-HTTP::Proxy's C<push_filte()> method).
+L<HTTP::Proxy>'s C<push_filter()> method).
 
 =back
 
@@ -363,7 +365,7 @@ options:
 
 =head1 METHODS
 
-This filter implements several methods, which are all called atuomatically:
+This filter implements several methods, which are all called automatically:
 
 =over 4
 
@@ -409,7 +411,7 @@ Wget(1) provided the inspiration for many of the file naming options.
 
 Thanks to Nicolas Chuche for telling me about C<O_EXCL>.
 
-Thanks to Rafal Garcia-Suarez and David Rigaudiere for their help on
+Thanks to Rafaël Garcia-Suarez and David Rigaudiere for their help on
 irc while coding the nasty C<begin()> method. C<;-)>
 
 Thanks to Howard Jones for the inspiration and initial patch for the
@@ -430,7 +432,7 @@ L<http://rt.cpan.org/Ticket/Display.html?id=33018>).
 
 =head1 COPYRIGHT
 
-Copyright 2004-2008, Philippe Bruhat.
+Copyright 2004-2015, Philippe Bruhat.
 
 =head1 LICENSE
 
