@@ -1,5 +1,5 @@
 package HTTP::Proxy::HeaderFilter::standard;
-
+$HTTP::Proxy::HeaderFilter::standard::VERSION = '0.302';
 use strict;
 use HTTP::Proxy;
 use HTTP::Headers::Util qw( split_header_words );
@@ -90,7 +90,7 @@ sub filter {
     # no encoding accepted (gzip, compress, deflate)
     # if we plan to do anything with the response body
     $headers->remove_header( 'Accept-Encoding' )
-        if @{ $self->proxy->{body}{response}{current} || [] };
+        if @{ $self->proxy->{body}{response}{filters} };
 }
 
 1;
@@ -119,6 +119,10 @@ C<X-Forwarded-For:> headers (except when the proxy was instructed not
 to add them), decrementing the C<Max-Forwards:> header and removing
 the hop-by-hop and L<LWP::UserAgent> headers.
 
+Note that the filter will automatically remove the C<Accept-Encoding>
+headers if the proxy has at least one L<HTTP::Proxy::BodyFilter> filter.
+(This is to ensure that the filters will receive uncompressed data.)
+
 =back
 
 =head1 SEE ALSO
@@ -134,7 +138,7 @@ hop-by-hop headers.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2013, Philippe Bruhat.
+Copyright 2003-2015, Philippe Bruhat.
 
 =head1 LICENSE
 
